; --COPYRIGHT--,BSD_EX
;  Copyright (c) 2013, Texas Instruments Incorporated
;  All rights reserved.
; 
;  Redistribution and use in source and binary forms, with or without
;  modification, are permitted provided that the following conditions
;  are met:
; 
;  *  Redistributions of source code must retain the above copyright
;     notice, this list of conditions and the following disclaimer.
; 
;  *  Redistributions in binary form must reproduce the above copyright
;     notice, this list of conditions and the following disclaimer in the
;     documentation and/or other materials provided with the distribution.
; 
;  *  Neither the name of Texas Instruments Incorporated nor the names of
;     its contributors may be used to endorse or promote products derived
;     from this software without specific prior written permission.
; 
;  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
;  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
;  THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
;  PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
;  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
;  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
;  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
;  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
;  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
;  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
;  EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
; 
; ******************************************************************************
;  
;                        MSP430 CODE EXAMPLE DISCLAIMER
; 
;  MSP430 code examples are self-contained low-level programs that typically
;  demonstrate a single peripheral function or device feature in a highly
;  concise manner. For this the code may rely on the device's power-on default
;  register values and settings such as the clock configuration and care must
;  be taken when combining code from several examples to avoid potential side
;  effects. Also see www.ti.com/grace for a GUI- and www.ti.com/msp430ware
;  for an API functional library-approach to peripheral configuration.
; 
; --/COPYRIGHT--
;******************************************************************************
;  MSP430i20xx Demo - eUSCI_B0, SPI 3-Wire Master Incremented Data
;
;  Description: SPI master talks to SPI slave using 3-wire mode. Incrementing
;  data is sent by the master starting at 0x01. Received data is expected to
;  be same as the previous transmission TXData = RXData-1.
;
;  ACLK = 32kHz, MCLK = SMCLK = Calibrated DCO = 16.384MHz
;  * Ensure low_level_init.asm is included when building/running this example *
;
;  Note: Ensure slave is powered up before master to prevent delays due to
;  slave init
;
;           MSP430i20xx
;         ----------------
;     /|\|                |
;      | |                |
;      --|RST             |
;        |            P1.7|--> Data Out      (UCA0SIMO)
;        |            P1.6|<-- Data In       (UCA0SOMI)
;        |            P1.5|--> Serial Clock (UCA0CLK)
;
;   T. Witt
;   Texas Instruments Inc.
;   October 2013
;   Built with Code Composer Studio v5.5
;******************************************************************************
;-------------------------------------------------------------------------------
            .cdecls C,LIST,"msp430.h"       ; Include device header file
;-------------------------------------------------------------------------------
            .def    RESET                   ; Export program entry-point to
                                            ; make it known to linker.
RXData      .set    R7
TXData      .set    R8
;-------------------------------------------------------------------------------
            .global __STACK_END
            .sect   .stack                  ; Make stack linker segment known

            .text                           ; Assemble to Flash memory
            .retain                         ; Ensure current section gets linked
            .retainrefs

            .ref    init                    ; Reference external function

RESET       mov.w   #__STACK_END,SP         ; Initialize stackpointer
Cal         call    #init                   ; Calibrate peripherals
StopWDT     mov.w   #WDTPW|WDTHOLD,&WDTCTL  ; Stop WDT
            bis.b   #BIT5|BIT6|BIT7,&P1SEL0 ; eUSCI_A0 Pin Function
            bic.b   #BIT5|BIT6|BIT7,&P1SEL1
            mov.w   #UCSWRST,&UCB0CTLW0     ; eUSCI in reset
            bis.w   #UCMST|UCSYNC|UCCKPL|UCMSB,&UCB0CTLW0
            ; 3-pin, 8-bit SPI master, Clock polarity high, MSB
            bis.w   #UCSSEL_1,&UCB0CTLW0    ; ACLK
            mov.b   #0x02,&UCB0BR0
            clr.b   &UCB0BR1
            bic.w   #UCSWRST,&UCB0CTLW0     ; Initialize eUSCI
            bis.w   #UCRXIE,&UCB0IE         ; Enable RX interrupt
            mov.b   #0x01,TXData

Mainloop    bis.w   #UCTXIE,&UCB0IE         ; Enable TX interrupt
            bis.w   #LPM0|GIE,SR            ; Enter LPM0 with interrupts
            mov.w   #32000,R15              ; Delay loop
Delay       dec.w   R15
            jnz     Delay
            inc.b   TXData
            jmp     Mainloop                ; Again
                                            ;
;-------------------------------------------------------------------------------
USCI_B0_ISR    ; eUSCI_B0 ISR
;-------------------------------------------------------------------------------
            add.w   &UCB0IV,PC              ; Add interrupt offset
            reti                            ; No interrupt
            jmp     RXIFG_                  ; RXIFG
            jmp     TXIFG_                  ; TXIFG
RXIFG_      mov.w   &UCB0RXBUF,RXData       ; Save RX'ed Data
            bic.w   #UCRXIFG,&UCB0IFG       ; Clear IFG
            bic.w   #LPM0,0(SP)             ; Wake up from LPM0
            reti
TXIFG_      mov.w   TXData,&UCB0TXBUF       ; Transmit character
            bic.w   #UCTXIE,&UCB0IE         ; Disable TX interrupt
            reti

;-------------------------------------------------------------------------------
;           Interrupt Vectors
;-------------------------------------------------------------------------------
            .sect   ".reset"                ; MSP430 RESET Vector
            .short  RESET
            .sect   ".int08"                ; eUSCI_B0 Vector
            .short  USCI_B0_ISR
            .end
